using namespace std;
#include <fstream>
#include<iostream>
#include<vector>
#include<cmath>
#include<cassert>
#include<cstdio>
#include <string>

typedef unsigned int u32;

struct SegmentTree{
	vector<int> M;
	vector<int> pending;

	SegmentTree(int m){
		M.resize((m << 2) + 4);
		pending.resize((m << 2) + 4);
	}

	void init(vector<int> &data, int node, int a, int b){
		pending[node] = 0;
		if (a == b){
			M[node] = data[a];
		}
		else{
			init(data, node << 1, a, (a + b) >> 1);
			init(data, (node << 1) + 1, ((a + b) >> 1) + 1, b);
			M[node] = M[node << 1] + M[(node << 1) + 1];
		}
	}

	void propagate(int node, int a, int b){
		if (pending[node] == 0) return;
		if (pending[node] == 1){
			M[node] = (b - a + 1);
			if (a != b)
				pending[node << 1] = pending[(node << 1) + 1] = 1;

		}
		else if (pending[node] == 2){
			M[node] = 0;
			if (a != b)
				pending[node << 1] = pending[(node << 1) + 1] = 2;

		}
		else{
			M[node] = (b - a + 1) - M[node];
			assert((b - a + 1) >= M[node]);
			if (a != b){
				if (pending[node << 1] != 0) pending[node << 1] = (pending[node << 1] != 3) ? (pending[node << 1] == 2) ? 1 : 2 : 0;
				else pending[node << 1] = 3;
				if (pending[(node << 1) + 1] != 0) pending[(node << 1) + 1] = (pending[(node << 1) + 1] != 3) ? (pending[(node << 1) + 1] == 2) ? 1 : 2 : 0;
				else pending[(node << 1) + 1] = 3;
			}
		}
		pending[node] = 0;
	}

	void set_bits(int node, int a, int b, int i, int j){
		propagate(node, a, b);
		if (a > j || b < i) return;
		if (a >= i && b <= j){
			M[node] = (b - a + 1);
			assert((b - a + 1) > 0);
			if (a != b)
				pending[node << 1] = pending[(node << 1) + 1] = 1;
		}
		else{
			set_bits(node << 1, a, (a + b) >> 1, i, j);
			set_bits((node << 1) + 1, ((a + b) >> 1) + 1, b, i, j);
			M[node] = M[node << 1] + M[(node << 1) + 1];
		}
	}

	void clear_bits(int node, int a, int b, int i, int j){
		propagate(node, a, b);
		if (a > j || b <i) return;
		if (a >= i && b <= j){
			M[node] = 0;
			if (a != b)
				pending[node << 1] = pending[(node << 1) + 1] = 2;
		}
		else{
			clear_bits(node << 1, a, (a + b) >> 1, i, j);
			clear_bits((node << 1) + 1, ((a + b) >> 1) + 1, b, i, j);
			M[node] = M[node << 1] + M[(node << 1) + 1];
		}
	}

	void flip(int node, int a, int b, int i, int j){
		propagate(node, a, b);
		if (a> j || b <i) return;
		if (a >= i && b <= j){
			M[node] = (b - a + 1) - M[node];
			assert((b - a + 1) >= M[node]);
			if (a != b){
				if (pending[node << 1] != 0) pending[node << 1] = ((pending[node << 1] != 3) ? (pending[node << 1] == 2) ? 1 : 2 : 0);
				else pending[node << 1] = 3;
				if (pending[(node << 1) + 1] != 0) pending[(node << 1) + 1] = ((pending[(node << 1) + 1] != 3) ? (pending[(node << 1) + 1] == 2) ? 1 : 2 : 0);
				else pending[(node << 1) + 1] = 3;
			}
		}
		else{
			flip(node << 1, a, (a + b) >> 1, i, j);
			flip((node << 1) + 1, ((a + b) >> 1) + 1, b, i, j);
			M[node] = M[node << 1] + M[(node << 1) + 1];
		}
	}

	int query(int node, int a, int b, int i, int j){
		propagate(node, a, b);
		if (a>j || b < i) return 0;
		if (a >= i && b <= j)
			return M[node];
		else
			return query(node << 1, a, (a + b) >> 1, i, j) + query((node << 1) + 1, ((a + b) >> 1) + 1, b, i, j);
	}

};

char str[100];
SegmentTree tree(1024000);

int main() {
	ifstream fin;
	ofstream fout;
	fin.open("polsis.txt");
	fout.open("polval.txt");

	int N, M;
	fin >> N;
	fin >> M;
	vector<int> data;
	string s;
	getline(fin, s);
	getline(fin, s);
	for (int i = 0; i < N; i++)
	{
		data.push_back(s[i] == 'R');
	}

	int m = data.size();
	tree.init(data, 1, 0, m - 1);

	int qid = 1;
	while (M--){
		string op;
		fin >> op;
		int a, b;
		fin >> a;
		fin >> b;
		a--;
		b--;
		if (op[0] == 'K')
			tree.set_bits(1, 0, m - 1, a, b);
		else if (op[0] == 'R')
			tree.clear_bits(1, 0, m - 1, a, b);
		else if (op[0] == 'P')
			tree.flip(1, 0, m - 1, a, b);
		else
			fout << tree.query(1, 0, m - 1, a, b) << endl;
	}

	return 0;
}